@@ -258,8 +258,7 @@ void multiply_array(const BaseArray<T>& inputArray, const T& b, BaseArray<T>& ou
         outputArray.setDims(inputArray.getDims());
         const T* data = inputArray.getData();
         T* aim = outputArray.getData();
-        std::transform(data, data + inputArray.getNumElems(),
-                       aim, std::bind2nd(std::multiplies<T>(), b));
+        std::transform(data, data + inputArray.getNumElems(), aim, [&](const T& a) { return a*b; });
     }
 };
 
@@ -343,7 +342,7 @@ void divide_array(const BaseArray<T>& inputArray, const T& b, BaseArray<T>& outp
     }
     const T* data = inputArray.getData();
     T* aim = outputArray.getData();
-    std::transform(data, data + nelems, aim, std::bind2nd(std::divides<T>(), b));
+    std::transform(data, data + nelems, aim, [&](const T& a) { return a/b; });
 }
 
 template <typename T>
@@ -412,8 +411,7 @@ void subtract_array_scalar(const BaseArray<T>& inputArray, T b, BaseArray<T>& ou
         outputArray.setDims(inputArray.getDims());
         const T* data = inputArray.getData();
         T* aim = outputArray.getData();
-        std::transform(data, data + inputArray.getNumElems(),
-                       aim, std::bind2nd(std::minus<T>(), b));
+        std::transform(data, data + inputArray.getNumElems(), aim, [&](const T& a) { return a-b; });
     }
 }
 
@@ -444,8 +442,7 @@ void add_array_scalar(const BaseArray<T>& inputArray, T b, BaseArray<T>& outputA
         outputArray.setDims(inputArray.getDims());
         const T* data = inputArray.getData();
         T* result = outputArray.getData();
-        std::transform(data, data + inputArray.getNumElems(),
-                       result, std::bind2nd(std::plus<T>(), b));
+        std::transform(data, data + inputArray.getNumElems(), result, [&](const T& a) { return a+b; });
     }
 }
 
