@@ -277,8 +277,6 @@ private:
 
     CoordinateSystem mCoordinateSystem;
     CoordinateSystem mMergedCoOrdinateSystem;
-
-    static IconDiagramAnnotation defaultIconDiagramAnnotation;
   private:
     Model *mpParentModel;
     QList<Shape*> mGraphics;
@@ -397,8 +395,8 @@ private:
     ~Annotation();
     void deserialize(const QJsonObject &jsonObject);
 
-    IconDiagramAnnotation *getIconAnnotation() const;
-    IconDiagramAnnotation *getDiagramAnnotation() const;
+    IconDiagramAnnotation *getIconAnnotation() const {return mpIconAnnotation.get();}
+    IconDiagramAnnotation *getDiagramAnnotation() const {return mpDiagramAnnotation.get();}
     const BooleanAnnotation &isState() const {return mState;}
     // Element annotation
     const BooleanAnnotation &isChoicesAllMatching() const {return mChoicesAllMatching;}
@@ -584,6 +582,7 @@ private:
     const QString &getName() const {return mName;}
     const QString &getRootType() const;
     bool isMissing() const {return mMissing;}
+    void setRestriction(const QString &restriction) {mRestriction = restriction;}
     const QString &getRestriction() const {return mRestriction;}
     bool isConnector() const;
     bool isExpandableConnector() const;
