@@ -286,7 +286,13 @@ void Label::setText(const QString &text)
 {
   mText = text;
   setToolTip(text);
-  QLabel::setText(elidedText());
+  const QString text1 = elidedText();
+  // if text is empty OR if we get "..." i.e., QChar(0x2026) as text
+  if (text1.isEmpty() || text1.compare(QChar(0x2026)) == 0) {
+    QLabel::setText(mText);
+  } else {
+    QLabel::setText(text1);
+  }
 }
 
 QString Label::elidedText() const
@@ -643,7 +649,7 @@ bool Utilities::isValueLiteralConstant(QString value)
    * Issue #11840. Allow setting array of values.
    * The following regular expression allows decimal values and array of decimal values. The values can be negative.
    */
-  QRegExp rx("\\{?\\s*-?\\d+(\\.\\d+)?(?:\\s*,\\s*-?\\d+(\\.\\d+)?)*\\s*\\}?");
+  QRegExp rx("\\{?\\s*-?\\d+(\\.\\d+)?([eE][-+]?\\d+)?(?:\\s*,\\s*-?\\d+(\\.\\d+)?([eE][-+]?\\d+)?)*\\s*\\}?");
   return rx.exactMatch(value);
 }
 
