@@ -193,11 +193,7 @@ void Draw_Text::setRotate(const QPointF &pnt,const QPointF &pnt1) {
 
 void Draw_Text::setScale(float x,float y)
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
    item->setTransform(QTransform::fromScale(x, y), true);
-#else
-   item->scale(x,y);
-#endif
 }
 
 void Draw_Text::showHandles() {
